Most automated tools are not able to analyze the security of client-side
technologies such as Flash and Java applets. This informational finding
serves as a heads-up to the information security specialist to review
the objects in question using a different method.